@@ -2,7 +2,7 @@
 #'
 #' @description Named vector of animals
 #'
-#' @details \code{animals} is a named character vector of animals,
+#' @details `animals` is a named character vector of animals,
 #' with each element a character string of variable length specifying
 #' an ASCII animal. Note that some have unicode characters that won't
 #' play well on some operating systems.
@@ -13,8 +13,8 @@
 #' animals[['clippy']]
 animals <- c(
   cow = "\n ----- \n%s \n ------ \n    \\\   ^__^ \n     \\\  (oo)\\\ ________ \n        (__)\\\         )\\\ /\\\ \n             ||------w|\n             ||      ||"
-  ,chicken = "
-\n ----- \n%s \n ------ \n    \\\   \n     \\\
+  ,chicken = 
+"\n ----- \n%s \n ------ \n    \\\   \n     \\\
          _
        _/ }
       `>' \\\
@@ -27,9 +27,42 @@ animals <- c(
             _| _|
             /` /` [nosig]
   "
+,chuck = 
+"\n ----- \n%s \n ------ \n    \\\   \n     \\\
+                      @@@@@@@@@@@@@@                       
+                   @@@@@@@@@@@@@@@@@@@@@@                  
+                  @@@@@@@@@@@@@@@@@@@@@@@@@                
+                  @@@@@@@@@@@@@@@@@@@@@@@@@@               
+                  @@@@@@@@@@@@@@@@@@@@@@@@@@               
+                 @@@@@@@@@@@@@@@@@@@@@@@@@@@               
+                 @@@@@@@@@@@@@@@@@@@@@@@@@@@@              
+                @@@@@@@@@@@@@@@@@@@@@@@@@@@@@              
+                @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@     
+               @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@  
+ @             @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
+  @@           @@@@@@@@@@@@@@@@@@     @@@@@@@@@@@@@@@@@@@@@
+    @@@@@@@@@@@@@@@@    @@ @@@@         @@  @@@@@@@@@@@@@@@
+       @@@@@@@@@@@@@      @@@@          @@@@@@@@@@@@@@@@@@@
+          @@@@@@ @@@@@    @@@   @       @@@@@@@@@@ @@@@@@@ 
+              @@     @ @                @@ @@@@@@@@   @@@  
+                                              @@@@@@@  @   
+                @     @@                   @ @@@@@@@@@     
+                             @               @@@@@@@@ @@   
+                     @@@@@@@@@@          @  @@@@@          
+                  @@@@@@@@@@ @@           @@@@@  @         
+                 @@@@        @@ @          @@@  @          
+                  @@@           @          @@@             
+                   @@@@@@@   @@ @          @@@@@           
+                    @@@@@@@@@@            @@@@             
+                     @@@@@@ @     @     @@@@@@@@           
+                  @@ @ @@@@@@@@@ @@@@@@@@@@@@@@@@@         
+                @@@  @@@@@   @@@@@@@@@@@@@@@@@@@@@         
+      @@@@@@  @@@@@   @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@   
+@@    @@@@  @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@ [nosig]
+  "
+
   ,clippy = "
-\n ----- \n%s \n ------ \n    \\\   \n     \\\
-   __
+\n ----- \n%s \n ------ \n    \\\   \n     \\\   __
    / \\
    | |
    @ @
@@ -39,8 +72,7 @@ animals <- c(
   \\___/ GB
 "
   ,poop =
-    "
-\n ----- \n%s \n ------ \n    \\\   \n     \\\
+"\n ----- \n%s \n ------ \n    \\\   \n     \\\
      (   )
   (   ) (
    ) _   )
@@ -49,8 +81,7 @@ animals <- c(
  (____\\\ ___)) [nosig]"
 
   ,bigcat =
-    "
-\n ----- \n%s \n ------ \n    \\\   \n     \\\
+"\n ----- \n%s \n ------ \n    \\\   \n     \\\
                 \\`*-.
                  )  _`-.
                 .  : `. .
@@ -68,8 +99,7 @@ animals <- c(
     "
 
   ,ant =
-  "
-\n ----- \n%s \n ------ \n    \\\   \n     \\\
+"\n ----- \n%s \n ------ \n    \\\   \n     \\\
        '\\__
       (o )     ___
       <>(_)(_)(___)
@@ -78,8 +108,7 @@ animals <- c(
   "
 
   ,pumpkin =
-  "
-\n ----- \n%s \n ------ \n    \\\   \n     \\\
+"\n ----- \n%s \n ------ \n    \\\   \n     \\\
                   ___
                ___)__|_
           .-*'          '*-,
@@ -92,8 +121,7 @@ animals <- c(
   "
 
   ,ghost =
-  "
-\n ----- \n%s \n ------ \n    \\\   \n     \\\
+"\n ----- \n%s \n ------ \n    \\\   \n     \\\
      .-.
     (o o)
     | O \\\
@@ -102,8 +130,7 @@ animals <- c(
   "
 
   ,spider =
-  "
-\n ----- \n%s \n ------ \n    \\\   \n     \\\
+"\n ----- \n%s \n ------ \n    \\\   \n     \\\
               |
               |
               |
@@ -115,16 +142,14 @@ animals <- c(
   "
 
   ,rabbit =
-  "
-\n ----- \n%s \n ------ \n    \\\   \n     \\\
+"\n ----- \n%s \n ------ \n    \\\   \n     \\\
       ( )_( )
       (='.'=)
       (^)_(^) [nosig]
   "
 
   ,pig =
-  "
-\n ----- \n%s \n ------ \n    \\\   \n     \\\
+"\n ----- \n%s \n ------ \n    \\\   \n     \\\
        _//| .-~~~-.
      _/oo  }       }-@
     ('')_  }       |
@@ -133,8 +158,7 @@ animals <- c(
   "
 
   ,snowman =
-  '
-\n ----- \n%s \n ------ \n    \\\   \n     \\\
+'\n ----- \n%s \n ------ \n    \\\   \n     \\\
      _[_]_
       (")
   >--( : )--<
@@ -142,8 +166,7 @@ animals <- c(
   '
 
   ,frog =
-  "
-\n ----- \n%s \n ------ \n    \\\   \n     \\\
+"\n ----- \n%s \n ------ \n    \\\   \n     \\\
         (.)_(.)
      _ (   _   ) _
     / \\/`-----'\\/ \\
@@ -155,8 +178,7 @@ animals <- c(
   # From here:
   # http://chris.com/ascii/index.php?art=television/futurama
   ,hypnotoad =
-  "
-\n ----- \n%s \n ------
+"\n ----- \n%s \n ------
     \\\          ,'``.._   ,'``.
      \\\        :,--._:)\\,:,._,.:
       \\\       :`--,''   :`...';\\
@@ -181,8 +203,7 @@ animals <- c(
   # From here:
   # https://twitter.com/BoingBoing/status/465170473194512384
   ,shortcat =
-  '
-\n ----- \n%s \n ------ \n    \\\   \n     \\\
+'\n ----- \n%s \n ------ \n    \\\   \n     \\\
     .\uFF8A,,\uFF8A
     ( \uFF9F\u03C9\uFF9F)
     |\u3064  \u3064
@@ -191,8 +212,7 @@ animals <- c(
     '
 
   ,longcat =
-    '
-\n ----- \n%s \n ------ \n    \\\   \n     \\\
+'\n ----- \n%s \n ------ \n    \\\   \n     \\\
     .\uFF8A,,\uFF8A
     ( \uFF9F\u03C9\uFF9F)
     |\u3064  \u3064
@@ -202,8 +222,7 @@ animals <- c(
     '
 
   ,fish =
-    '
-\n ----- \n%s \n ------ \n    \\\   \n     \\\
+'\n ----- \n%s \n ------ \n    \\\   \n     \\\
   ><((((\u00BA>  ><((((\u00BA>  ><((((\u00BA>  ><((((\u00BA>  ><((((\u00BA>
       Kiyoko Gotanda
     '
@@ -306,8 +325,7 @@ Jill                    `;;\u201B             ;   ; ;
   '
 
   ,trilobite =
-  "
-  \n -------------- \n%s \n --------------
+  "\n -------------- \n%s \n --------------
     \u005c
       \u005c
         \u005c
@@ -323,8 +341,8 @@ Jill                    `;;\u201B             ;   ; ;
   "
 
   ,shark =
-    "
-    \n -------------- \n%s \n --------------
+
+  "\n -------------- \n%s \n --------------
     \u005c
       \u005c
         \u005c
@@ -355,8 +373,7 @@ Jill                    `;;\u201B             ;   ; ;
   "
 
   ,buffalo =
-  "
-    \n -------------- \n%s \n --------------
+"\n -------------- \n%s \n --------------
     \u005c
       \u005c
         \u005c
@@ -376,8 +393,7 @@ Jill                    `;;\u201B             ;   ; ;
 
 
   ,grumpycat =
-  '
-   \n -------------- \n%s \n --------------
+  '\n -------------- \n%s \n --------------
     \u005c
       \u005c
         \u005c
@@ -386,8 +402,7 @@ Jill                    `;;\u201B             ;   ; ;
   '
 
   ,smallcat =
-  '
-   \n -------------- \n%s \n --------------
+  '\n -------------- \n%s \n --------------
     \u005c
      \u005c
       \u005c
@@ -395,9 +410,8 @@ Jill                    `;;\u201B             ;   ; ;
         ( o.o )
          > ^ <      [nosig]\n\n' # from https://user.xmission.com/~emailbox/ascii_cats.htm
 
-  ,yoda = "
-
-\n ----- \n%s \n ------ \n    \\\   \n     \\\
+  ,yoda = 
+"\n ----- \n%s \n ------ \n    \\\   \n     \\\
                    ____
                 _.' :  `._
             .-.'`.  ;   .'`.-.
@@ -434,8 +448,8 @@ Jill                    `;;\u201B             ;   ; ;
                \\ `t  ._  /  bug
                 \"-.t-._:'
   "
-  , mushroom = "
-\n ----- \n%s \n ------ \n    \\\   \n     \\\  \n      \\\
+  , mushroom = 
+"\n ----- \n%s \n ------ \n    \\\   \n     \\\  \n      \\\
                 ________
            __--\u00B4      \u00B0 `--__
        __-\u00B4     \u00B0      \u00B0     `-__
@@ -452,8 +466,7 @@ Jill                    `;;\u201B             ;   ; ;
                  |_____|
 ",  # Franz-Sebastian Krah
   endlesshorse =
-"
-\n ----- \n%s \n ------ \n    \\\   \n     \\\  \n      \\\
+"\n ----- \n%s \n ------ \n    \\\   \n     \\\  \n      \\\
        ,
     _,,)\\.~,,._
      (()`  ``)\\))),,_
@@ -473,8 +486,7 @@ Jill                    `;;\u201B             ;   ; ;
                     | | | |             || |",
 
 bat =
-"
-\n ------------- \n%s \n -------------- \n              \\\   \n               \\\  \n                \\\
+"\n ------------- \n%s \n -------------- \n              \\\   \n               \\\  \n                \\\
         __.--'\\     \\.__./     /'--.__
     _.-'       '.__.'    '.__.'       '-._
   .'                                      '.
@@ -487,8 +499,7 @@ bat =
                       ''mrf
 ",
 bat2 =
-"
-\n ------------- \n%s \n -------------- \n              \\\   \n               \\\  \n                \\\
+"\n ------------- \n%s \n -------------- \n              \\\   \n               \\\  \n                \\\
 _____________________                              _____________________
 `-._                 \\           |\\__/|           /                 _.-'
     \\                 \\          |    |          /                 /
@@ -506,8 +517,7 @@ _____________________                              _____________________
                                    \\/
 ",
 turkey =
-"
-\n ------------- \n%s \n -------------- \n              \\\   \n               \\\  \n                \\\
+"\n ------------- \n%s \n -------------- \n              \\\   \n               \\\  \n                \\\
                .--.
               /} p \\             /}
              `~)-) /           /` }
@@ -523,8 +533,7 @@ turkey =
                    .=='=,
 ",
 monkey =
-"
-\n ------------- \n%s \n -------------- \n              \\\   \n               \\\  \n                \\\
+"\n ------------- \n%s \n -------------- \n              \\\   \n               \\\  \n                \\\
 
                   .=\"=.
                 _/.-.-.\\_     _
@@ -605,6 +614,36 @@ owl =
        |    \\ \\
         \\___/_/       [ab] 
           | | 
+",
+# squirrel by Marion Louveaux, @marionlouveaux
+squirrel = 
+  "             ------ \n          %s \n             ------ \n                 \\\   \n                  \\\  \n                   \\\
+                      . .     
+                      |\\|\\_   
+                      /  ^ \\  
+                     /  _-_/\u00B0 
+   \\\\\\\\\\\\\\\\\\       /   / \\    
+  ////////////   /  \\ / ||    
+ \\\\\\\\\\\\\\\\\\\\\\\\\\\\ /   /\\\\ \\\\    
+////////////////   /  \\\\ \\\\   
+ \\\\\\\\\\\\\\\\\\\\\\\\\\/   /  / `` ``  
+     /////////   \\  /  \\      
+ ML     \\\\\\\\\\\\___/_/___/      
+",
+# squirrel2 by Marion Louveaux, @marionlouveaux
+ squirrel2 =
+  "             ------ \n          %s \n             ------ \n                 \\\   \n                  \\\  \n                   \\\
+                      . .     
+                      |\\|\\_   
+                      /  @ \\  
+                     /  _-_/\u00B0 
+   \\\\\\\\\\\\\\\\\\       /   / \\    
+  ////////////   /  \\ / ||    
+ \\\\\\\\\\\\\\\\\\\\\\\\\\\\ /   /\\\\ \\\\    
+////////////////   /  \\\\ \\\\   
+ \\\\\\\\\\\\\\\\\\\\\\\\\\/   /  / `` ``  
+     /////////   \\  /  \\      
+ ML     \\\\\\\\\\\\___/_/___/      
 "
 )
 
